@@ -14,6 +14,9 @@ use Couchbase::Settings;
 use Couchbase::OpContext;
 use Couchbase::View::Handle;
 use Couchbase::View::HandleInfo;
+use Couchbase::View::Handle::RawIterator;
+use Couchbase::View::Handle::ViewIterator;
+use Couchbase::View::Handle::Slurpee;
 
 my $_JSON = JSON->new()->allow_nonref;
 sub _js_encode { $_JSON->encode($_[0]) }
@@ -481,6 +484,19 @@ This version of the client uses so-called "Common Flags", allowing seamless inte
 with Couchbase clients written in other languages.
 
 
+=head4 Encoding Formats
+
+Bear in mind that Perl's default encoding is I<Latin-1> and not I<UTF-8>. To
+that effect, any input, unless indicated otherwise, is assumed to thus be
+Latin-1. There are various ways to change the "type" of a string, the details
+of which can be found within the L<utf8> and L<Encode> modules.
+
+From the perspective of this module, any I<input> string which is marked
+as being JSON or UTF8 will be marked as being UTF-8. This may mean some
+smaller performance implications. If this is a concern, you can intercept
+the JSON decoding function and handle the raw string there.
+
+
 =head4 CAS Operations
 
 To avoid race conditions when two applications attempt to write to the same document
@@ -727,6 +743,21 @@ rows themselves may be found inside the C<rows> accessor:
     }
 
 
+This method returns an instance of L<Couchbase::View::HandleInfo> which may be used
+to inspect for error messages. The object is in fact a subclass of
+L<Couchbase::Document> with an additional C<errinfo> method to provide more
+details about the operation.
+
+    if (!$rv->is_ok) {
+        if ($rv->errnum) {
+            # handle error code
+        }
+        if ($rv->http_code !~ /^2/) {
+            # Failed HTTP status
+        }
+    }
+
+
 =head3 view_iterator("design/view", %options)
 
 This works in much the same way as the C<view_slurp()> method does, except
@@ -739,6 +770,31 @@ query to return a large amount of results:
         printf("Got row for key %s with document id %s\n", $row->key, $row->id);
     }
 
+Note that unlike the C<view_slurp> method, this does I<not> return a
+C<HandleInfo> object, but rather a L<Couchbase::View::Handle::ViewIterator>. The
+actual C<HandleInfo> object can be obtained using the C<info> method of the
+iterator. Note that the contents of the C<HandleInfo> object are only
+considered valid once the iterator has been through at least I<one> iteration;
+thus:
+
+B<Incorrect>, because it requests the C<info> object before iteration has
+started
+
+    my $iter = $cb->view_iterator($dpath);
+    if (!$iter->info->is_ok) {
+        # ...
+    }
+
+B<Correct>
+
+    my $iter = $cb->view_iterator($dpath);
+    while (my $row = $iter->next) {
+        # ...
+    }
+    if (!$iter->info->is_ok) {
+        # ...
+    }
+
 
 =head2 INFORMATIONAL METHODS
 
